from boodle.agent import *

# noise - a module for Andrew Plotkin's boodler
#
# (See http://www.eblong.com/zarf/boodler/index.html)
#
# Created by Paul Mazaitis. This code file is in the public domain,
# with no warranty whatsoever. The white.aiff sample is also in the
# public domain. The other sound files come from
# http://www.dogstar.dantimax.dk/testwavs/ -- they were created by
# Fred Nachbaur and "may be freely used for personal, non-commercial
# use only."
#
# This module consists of this file, which should be placed in your
# boodler effects path, and the sound files pure/*.aiff, which should
# be placed in the boodler sound repository, under the directory
# pure.
#
# Each sound file is ten seconds long. The accompanying agents just
# play the sound in a repeating loop. This is not true noise, of
# course -- true noise doesn't repeat -- but it sounds right.
#
# White noise: frequency distribution is 1 (flat)
# Pink noise: distribution is 1/f (a 3 dB drop per octave)
# Blue noise: distribution is f (3 dB rise per octave)
# Brown noise: distribution is 1/f^2 (6 dB drop per octave)
# Violet noise: distribution is f^2 (6 dB rise per octave)

white_snd  = 'pure/white.aiff'
pink_snd   = 'pure/pink.aiff'
blue_snd   = 'pure/blue.aiff'
brown_snd  = 'pure/brown.aiff'
violet_snd = 'pure/violet.aiff'

class White(Agent):
	name = 'white noise'
	def __init__(self, pitch=1.0):
		Agent.__init__(self)
		self.pitch = float(pitch)
	def run(self):
		dur = self.sched_note(white_snd, self.pitch)
		self.resched(dur)

class Pink(Agent):
	name = 'pink noise'
	def __init__(self, pitch=1.0):
		Agent.__init__(self)
		self.pitch = float(pitch)
	def run(self):
		dur = self.sched_note(pink_snd, self.pitch)
		self.resched(dur)

class Blue(Agent):
	name = 'blue noise'
	def __init__(self, pitch=1.0):
		Agent.__init__(self)
		self.pitch = float(pitch)
	def run(self):
		dur = self.sched_note(blue_snd, self.pitch)
		self.resched(dur)

class Brown(Agent):
	name = 'brown noise'
	def __init__(self, pitch=1.0):
		Agent.__init__(self)
		self.pitch = float(pitch)
	def run(self):
		dur = self.sched_note(brown_snd, self.pitch)
		self.resched(dur)

class Violet(Agent):
	name = 'violet noise'
	def __init__(self, pitch=1.0):
		Agent.__init__(self)
		self.pitch = float(pitch)
	def run(self):
		dur = self.sched_note(violet_snd, self.pitch)
		self.resched(dur)


